<?php
header('Expires: Sun, 01 Jan 2014 00:00:00 GMT');
header('Cache-Control: no-store, no-cache, must-revalidate');
header('Cache-Control: post-check=0, pre-check=0', FALSE);
header('Pragma: no-cache');

// read cookie contents
$cookie = isset($_COOKIE['cart_items_cookie']) ? $_COOKIE['cart_items_cookie'] : "";
$cookie = stripslashes($cookie);
$saved_cart_items = json_decode($cookie, true);

if($_POST){

	// include classes
	include_once "config/database.php";
	include_once "libs/php/util.php";
	include_once "objects/product.php";
	include_once "objects/category.php";
	include_once "objects/order.php";
	include_once "objects/order_item.php";

	// get database connection
	$database = new Database();
	$db = $database->getConnection();

	// initialize objects
	$util = new Util();
	$product = new Product($db);
	$category = new Category($db);
	$order = new Order($db);
	$order_item = new OrderItem($db);

	// posted values
	$customer_name=isset($_POST['name']) ? htmlspecialchars(strip_tags($_POST['name'])) : "";
	$customer_address=isset($_POST['address']) ? htmlspecialchars(strip_tags($_POST['address'])) : "";
	$customer_phone=isset($_POST['phone']) ? htmlspecialchars(strip_tags($_POST['phone'])) : "";
	$customer_email=isset($_POST['email']) ? htmlspecialchars(strip_tags($_POST['email'])) : "";

	// get the product ids
	$ids = array();
	foreach($saved_cart_items as $id=>$name){
		array_push($ids, $id);
	}

	if(count($ids)>0){

		// generate unique transaction id
		$transaction_id=strtoupper(uniqid());

		// initialize total price and item count
		$total_price=0;
		$item_count=0;

		// get the product ids
		$stmt=$product->readByIds($ids);

		// html table to be sent to admin email
		$body="";

		$body.="<table cellpadding='8'>";
		$body.="<tr><td>Dear Admin,</td></tr>";
		$body.="<tr><td>Someone sent an order.</td></tr>";
		$body.="</table>";

		$body.="<table cellpadding='8'>";
			$body.="<tr>";
				$body.="<td>Name:</td>";
				$body.="<td>{$customer_name}</td>";
			$body.="</tr>";
			$body.="<tr>";
				$body.="<td>Address:</td>";
				$body.="<td>{$customer_address}</td>";
			$body.="</tr>";
			$body.="<tr>";
				$body.="<td>Phone:</td>";
				$body.="<td>{$customer_phone}</td>";
			$body.="</tr>";
			$body.="<tr>";
				$body.="<td>Email:</td>";
				$body.="<td>{$customer_email}</td>";
			$body.="</tr>";
		$body.="</table>";

		$body.="<table cellpadding='8'>";
		$body.="<tr>";
			$body.="<td><b>Product</b></td>";
			$body.="<td><b>Pice</b></td>";
			$body.="<td><b>Quantity</b></td>";
		$body.="</tr>";

		while ($row = $stmt->fetch(PDO::FETCH_ASSOC)){
			extract($row);

			$quantity=$saved_cart_items[$id]['quantity'];

			// html table
			$body.="<tr>";
				$body.="<td>{$name}</td>";
				$body.="<td>&#36;{$price}</td>";
				$body.="<td>{$quantity}</td>";
			$body.="</tr>";

			// set values to order item properties
			$order_item->transaction_id=$transaction_id;
			$order_item->product_id=$id;
			$order_item->price=$price;
			$order_item->quantity=$quantity;

			// create the order item
			$order_item->create();

			// compute subtotal
			$sub_total=$price*$quantity;

			// compute total price
			$total_price+=$sub_total;

			// subtract stock
			// get current stock
			$product->id=$id;
			$product->readOne();

			// subtract quantity in current stock
			$new_stock=$product->stock - $quantity;

			// save new stock
			$product->stock=$new_stock;
			$product->updateStock();

		}

		$body.="<tr>";
			$body.="<td></td>";
			$body.="<td>Total:</td>";
			$body.="<td>&#36;{$total_price}</td>";
		$body.="</tr>";

		$body.="<tr>";
			$body.="<td colspan='3'>You may reply to contact the customer.</td>";
		$body.="</tr>";

		$body.="</table>";

		// save order information
		$order->user_id="1"; // sample user id only
		$order->transaction_id=$transaction_id;
		$order->total_cost=$total_price;
		$order->status="Pending";
		$order->created=date("Y-m-d H:i:s");

		// create the order
		$order->create();

		// send order to admin via email
		$from_name=$customer_name;
		$from_email=$customer_email;
		$send_to_email="mike@codalify.com";
		$subject="New Order from {$customer_name}";
		$body=$body;
		$util->sendEmailViaPhpMail($from_name, $from_email, $send_to_email, $subject, $body);

		// redirect to empty cart
		header('Location: empty_cart.php?redirect_to=thank_you');
	}

	// tell the user no products found in his cart
	else{
		header('Location: cart.php?action=empty_cart');
	}

}
die();
?>
